@@ -86,15 +86,11 @@ SKIPPED_IMAGES = {
         "karbor-base",
         "kuryr-base",
         "monasca-base",
-        "neutron-bgp-dragent",
+        "monasca-thresh",
         "nova-mksproxy",
         "ovsdpdk",
         "searchlight-base",
-        "senlin-base",
         "solum-base",
-        # NOTE(jeffrey4l): There is no openstack-tripleo-ui package in
-        # centos queens repo
-        "tripleo-ui",
         "vmtp",
         "zun-base",
     ],
@@ -119,11 +115,13 @@ SKIPPED_IMAGES = {
         "kuryr-base",
         "mistral-event-engine",
         "monasca-base",
+        "monasca-thresh",
         "nova-mksproxy",
         "novajoin-base",
         "octavia-base",
+        # There is no qdrouterd package for ubuntu bionic
+        "qdrouterd",
         "searchlight-base",
-        "senlin-base",
         "solum-base",
         "tacker-base",
         "tripleo-ui",
@@ -133,6 +131,10 @@ SKIPPED_IMAGES = {
         "zun-base",
     ],
     'ubuntu+source': [
+        # There is no qdrouterd package for ubuntu bionic
+        "qdrouterd",
+        # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
+        # https://bugs.launchpad.net/tripleo/+bug/1744215
         "tripleo-ui"
     ],
     'debian+binary': [
@@ -150,11 +152,11 @@ SKIPPED_IMAGES = {
         "kuryr-base",
         "mistral-event-engine",
         "monasca-base",
+        "monasca-thresh",
         "nova-mksproxy",
         "novajoin-base",
         "octavia-base",
         "searchlight-base",
-        "senlin-base",
         "sensu-base",
         "solum-base",
         "tacker-base",
@@ -177,15 +179,11 @@ SKIPPED_IMAGES = {
         "karbor-base",
         "kuryr-base",
         "monasca-base",
+        "monasca-thresh",
         "nova-mksproxy",
-        "neutron-bgp-dragent",
         "ovsdpdk",
         "searchlight-base",
-        "senlin-base",
         "solum-base",
-        # NOTE(jeffrey4l): There is no openstack-tripleo-ui package in
-        # centos queens repo
-        "tripleo-ui",
         "vmtp",
         "zun-base"
     ],
@@ -337,7 +335,7 @@ class PushTask(DockerTask):
                 self.success = False
 
     def push_image(self, image):
-        kwargs = dict(stream=True)
+        kwargs = dict(stream=True, decode=True)
 
         # Since docker 3.0.0, the argument of 'insecure_registry' is removed.
         # To be compatible, set 'insecure_registry=True' for old releases.
@@ -346,12 +344,11 @@ class PushTask(DockerTask):
             kwargs['insecure_registry'] = True
 
         for response in self.dc.push(image.canonical_name, **kwargs):
-            stream = json.loads(response)
-            if 'stream' in stream:
-                self.logger.info(stream['stream'])
-            elif 'errorDetail' in stream:
+            if 'stream' in response:
+                self.logger.info(response['stream'])
+            elif 'errorDetail' in response:
                 image.status = STATUS_ERROR
-                self.logger.error(stream['errorDetail']['message'])
+                self.logger.error(response['errorDetail']['message'])
 
 
 class BuildTask(DockerTask):
@@ -565,14 +562,15 @@ class BuildTask(DockerTask):
 
         buildargs = self.update_buildargs()
         try:
-            for response in self.dc.build(path=image.path,
-                                          tag=image.canonical_name,
-                                          nocache=not self.conf.cache,
-                                          rm=True,
-                                          pull=pull,
-                                          forcerm=self.forcerm,
-                                          buildargs=buildargs):
-                stream = json.loads(response.decode('utf-8'))
+            for stream in self.dc.build(path=image.path,
+                                        tag=image.canonical_name,
+                                        nocache=not self.conf.cache,
+                                        rm=True,
+                                        decode=True,
+                                        network_mode=self.conf.network_mode,
+                                        pull=pull,
+                                        forcerm=self.forcerm,
+                                        buildargs=buildargs):
                 if 'stream' in stream:
                     for line in stream['stream'].split('\n'):
                         if line:
@@ -981,9 +979,10 @@ class KollaWorker(object):
 
         skipped_images = SKIPPED_IMAGES.get('%s+%s' % (self.base,
                                                        self.install_type))
-        for image in self.images:
-            if image.name in skipped_images:
-                image.status = STATUS_UNMATCHED
+        if skipped_images:
+            for image in self.images:
+                if image.name in skipped_images:
+                    image.status = STATUS_UNMATCHED
 
     def summary(self):
         """Walk the dictionary of images statuses and print results."""
@@ -1253,8 +1252,6 @@ def run_build():
         squash_version = utils.get_docker_squash_version()
         LOG.info('Image squash is enabled and "docker-squash" version is %s',
                  squash_version)
-    else:
-        LOG.info('Image squash is disabled')
 
     kolla = KollaWorker(conf)
     kolla.setup_working_dir()
